graphium.features
====================
Feature extraction and manipulation

=== "Contents"

    * [Featurizer](#featurizer)
    * [Positional Encoding](#positional-encoding)
    * [Properties](#properties)
    * [Spectral PE](#spectral-pe)
    * [Random Walk PE](#random-walk-pe)
    * [NMP](#nmp)

## Featurizer
------------
::: graphium.features.featurizer


## Positional Encoding
------------
::: graphium.features.positional_encoding


## Properties
------------
::: graphium.features.properties


## Spectral PE
------------
::: graphium.features.spectral


## Random Walk PE
------------
::: graphium.features.rw


## NMP
------------
::: graphium.features.nmp
